Struct ExtIdleNotificationV1
pub struct ExtIdleNotificationV1 { /* private fields */ }wayland and Linux only.Expand description
idle notification
This interface is used by the compositor to send idle notification events to clients.
Initially the notification object is not idle. The notification object becomes idle when no user activity has happened for at least the timeout duration, starting from the creation of the notification object. User activity may include input events or a presence sensor, but is compositor-specific.
How this notification responds to idle inhibitors depends on how it was constructed. If constructed from the get_idle_notification request, then if an idle inhibitor is active (e.g. another client has created a zwp_idle_inhibitor_v1 on a visible surface), the compositor must not make the notification object idle. However, if constructed from the get_input_idle_notification request, then idle inhibitors are ignored, and only input from the user, e.g. from a keyboard or mouse, counts as activity.
When the notification object becomes idle, an idled event is sent. When user activity starts again, the notification object stops being idle, a resumed event is sent and the timeout is restarted.
See also the Request enum for this interface.
Implementations
impl ExtIdleNotificationV1
impl ExtIdleNotificationV1
pub fn idled(&self)
pub fn idled(&self)
notification object is idle
This event is sent when the notification object becomes idle.
It’s a compositor protocol error to send this event twice without a resumed event in-between.
pub fn resumed(&self)
pub fn resumed(&self)
notification object is no longer idle
This event is sent when the notification object stops being idle.
It’s a compositor protocol error to send this event twice without an idled event in-between. It’s a compositor protocol error to send this event prior to any idled event.